%global ver  1.46
%global archivever  jdk16-%(echo %{ver}|sed 's|\\\.||')
%global classname   org.bouncycastle.jce.provider.BouncyCastleProvider

Name:             bouncycastle1.46
Version:          %{ver}
Release:          2%{?dist}
Summary:          Bouncy Castle Crypto Package for Java

Group:            System Environment/Libraries
License:          MIT
URL:              http://www.bouncycastle.org/
# Use original sources from here on out.
Source0:          http://www.bouncycastle.org/download/bcprov-%{archivever}.tar.gz
Source1:          http://repo2.maven.org/maven2/org/bouncycastle/bcprov-jdk16/%{version}/bcprov-jdk16-%{version}.pom

BuildArch:        noarch
BuildRequires:    jpackage-utils
BuildRequires:    java-devel
BuildRequires:    junit

%description
The Bouncy Castle Crypto package is a Java implementation of cryptographic
algorithms. The package is organised so that it contains a light-weight API
suitable for use in any environment (including the newly released J2ME) with
the additional infrastructure to conform the algorithms to the JCE framework.


%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation
BuildArch:      noarch
Requires:       %{name} = %{version}-%{release}

%description javadoc
API documentation for the %{name} package.


%prep
%setup -q -n bcprov-%{archivever}

mkdir src
unzip -qq src.zip -d src/

cp -p %{SOURCE1} pom.xml

# Remove provided binaries
find . -type f -name "*.class" -exec rm -f {} \;
find . -type f -name "*.jar" -exec rm -f {} \;


%build
pushd src
  export CLASSPATH=$(build-classpath junit)
  %javac -g -source 1.6 -target 1.6 -encoding UTF-8 $(find . -type f -name "*.java")
  jarfile="../bcprov.jar"
  # Exclude all */test/* files except org.bouncycastle.util.test, cf. upstream
  files="$(find . -type f \( -name '*.class' -o -name '*.properties' \) -not -path '*/test/*')"
  files="$files $(find . -type f -path '*/org/bouncycastle/util/test/*.class')"
  files="$files $(find . -type f -path '*/org/bouncycastle/jce/provider/test/*.class')"
  files="$files $(find . -type f -path '*/org/bouncycastle/ocsp/test/*.class')"
  test ! -d classes && mf="" \
    || mf="`find classes/ -type f -name "*.mf" 2>/dev/null`"
  test -n "$mf" && jar cvfm $jarfile $mf $files \
    || %jar cvf $jarfile $files
popd


%install
# install bouncy castle provider
install -dm 755 %{buildroot}%{_javadir}
install -pm 644 bcprov.jar \
  %{buildroot}%{_javadir}/

# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}
cp -pr docs/* %{buildroot}%{_javadocdir}/%{name}

# maven pom
install -dm 755 %{buildroot}%{_mavenpomdir}
install -pm 644 %{SOURCE1} %{buildroot}%{_mavenpomdir}/JPP-bcprov.pom
# -v: compatibility package for %%{ver}
# -a: alias without flavour
%add_maven_depmap -v %{ver} -a org.bouncycastle:bcprov JPP-bcprov.pom bcprov.jar


%check
pushd src
  export CLASSPATH=$PWD:$(build-classpath junit4)
  for test in $(find . -name AllTests.class) ; do
    test=${test#./} ; test=${test%.class} ; test=${test//\//.}
    # TODO: failures; get them fixed and remove || :
    %java org.junit.runner.JUnitCore $test || :
  done
popd


%files -f .mfiles
%license LICENSE.html
%doc CONTRIBUTORS.html index.html releasenotes.html specifications.html

%files javadoc
%{_javadocdir}/%{name}/


%changelog
* Fri Mar 31 2017 František Dvořák <valtri@civ.zcu.cz> - 1.46-2
- Rebuilt for Indigo 2 and CMD

* Thu Sep 08 2016 František Dvořák <valtri@civ.zcu.cz> - 1.46-1
- Initial package (based on Fedora/EPEL)
